@@ -3,7 +3,6 @@ use std::fmt;
 use std::future::Future;
 use std::time::Duration;
 
-#[cfg(any(feature = "query", feature = "form", feature = "json"))]
 use serde::Serialize;
 #[cfg(feature = "json")]
 use serde_json;
@@ -16,9 +15,7 @@ use super::response::Response;
 use crate::config::{RequestConfig, TotalTimeout};
 #[cfg(feature = "multipart")]
 use crate::header::CONTENT_LENGTH;
-#[cfg(any(feature = "multipart", feature = "form", feature = "json"))]
-use crate::header::CONTENT_TYPE;
-use crate::header::{HeaderMap, HeaderName, HeaderValue};
+use crate::header::{HeaderMap, HeaderName, HeaderValue, CONTENT_TYPE};
 use crate::{Method, Url};
 use http::{request::Parts, Extensions, Request as HttpRequest, Version};
 
@@ -354,15 +351,9 @@ impl RequestBuilder {
     /// as `.query(&[("key", "val")])`. It's also possible to serialize structs
     /// and maps into a key-value pair.
     ///
-    /// # Optional
-    ///
-    /// This requires the optional `query` feature to be enabled.
-    ///
     /// # Errors
     /// This method will fail if the object you provide cannot be serialized
     /// into a query string.
-    #[cfg(feature = "query")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "query")))]
     pub fn query<T: Serialize + ?Sized>(mut self, query: &T) -> RequestBuilder {
         let mut error = None;
         if let Ok(ref mut req) = self.request {
@@ -416,16 +407,10 @@ impl RequestBuilder {
     /// # }
     /// ```
     ///
-    /// # Optional
-    ///
-    /// This requires the optional `form` feature to be enabled.
-    ///
     /// # Errors
     ///
     /// This method fails if the passed value cannot be serialized into
     /// url encoded format
-    #[cfg(feature = "form")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "form")))]
     pub fn form<T: Serialize + ?Sized>(mut self, form: &T) -> RequestBuilder {
         let mut error = None;
         if let Ok(ref mut req) = self.request {
@@ -479,6 +464,19 @@ impl RequestBuilder {
         self
     }
 
+    // This was a shell only meant to help with rendered documentation.
+    // However, docs.rs can now show the docs for the wasm platforms, so this
+    // is no longer needed.
+    //
+    // You should not otherwise depend on this function. It's deprecation
+    // is just to nudge people to reduce breakage. It may be removed in a
+    // future patch version.
+    #[doc(hidden)]
+    #[cfg_attr(target_arch = "wasm32", deprecated)]
+    pub fn fetch_mode_no_cors(self) -> RequestBuilder {
+        self
+    }
+
     /// Build a `Request`, which can be inspected, modified and executed with
     /// `Client::execute()`.
     pub fn build(self) -> crate::Result<Request> {
@@ -663,14 +661,15 @@ impl TryFrom<Request> for HttpRequest<Body> {
 
 #[cfg(test)]
 mod tests {
-    #![cfg(not(feature = "rustls-no-provider"))]
+    #![cfg(not(feature = "rustls-tls-manual-roots-no-provider"))]
 
-    use super::*;
-    #[cfg(feature = "query")]
+    use super::{Client, HttpRequest, Request, RequestBuilder, Version};
+    use crate::Method;
+    use serde::Serialize;
     use std::collections::BTreeMap;
+    use std::convert::TryFrom;
 
     #[test]
-    #[cfg(feature = "query")]
     fn add_query_append() {
         let client = Client::new();
         let some_url = "https://google.com/";
@@ -684,7 +683,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "query")]
     fn add_query_append_same() {
         let client = Client::new();
         let some_url = "https://google.com/";
@@ -697,7 +695,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "query")]
     fn add_query_struct() {
         #[derive(Serialize)]
         struct Params {
@@ -721,7 +718,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "query")]
     fn add_query_map() {
         let mut params = BTreeMap::new();
         params.insert("foo", "bar");
@@ -763,7 +759,6 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "query")]
     fn normalize_empty_query() {
         let client = Client::new();
         let some_url = "https://google.com/";
